# LPG Unified Planning integrator

## Installation

After cloning this repository run ```pip install up-lpg/```.

This repository incudes the LPG binaries compiled for Linux. The installation has been tested in Ubuntu 20.04.3 LTS.

### Features:
- One shot planning

